@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
+"""admin"""
 
 from django.contrib import admin
-import models
-admin.site.register(models.TestClass)
\ No newline at end of file
+from coop_cms.apps.test_app import models
+
+admin.site.register(models.TestClass)
