@@ -22,13 +22,15 @@ register = template.Library()
 
 ################################################################################
 class ArticleLinkNode(template.Node):
+    """create an article and returns a link into template"""
 
     def __init__(self, title, lang):
         self.title = title
         self.lang = lang
 
     def render(self, context):
-        Article = get_article_class()
+        """to html"""
+        article_class = get_article_class()
         
         try:
             v = template.Variable(self.title)
@@ -52,36 +54,44 @@ class ArticleLinkNode(template.Node):
                 elif hasattr(settings, 'LANGUAGE_CODE'):
                     lang = settings.LANGUAGE_CODE[:2]
                 article = get_article(slug, current_lang=lang)
-        except Article.DoesNotExist:
+        except article_class.DoesNotExist:
             try:
                 article = get_article(slug, all_langs=True)
-            except Article.DoesNotExist:
-                article = Article.objects.create(slug=slug, title=title)
+            except article_class.DoesNotExist:
+                article = article_class.objects.create(slug=slug, title=title)
         return article.get_absolute_url()
 
+
 @register.tag
 def article_link(parser, token):
+    """template tag"""
     args = token.split_contents()
     title = args[1]
     lang = args[2] if len(args) > 2 else None
     return ArticleLinkNode(title, lang)
 
+
 @register.filter
 def dehtml(value):
+    """html to text"""
     return do_dehtml(value)
-    
+
+
 @register.filter
 def sp_rt_lb(value):
+    """clean"""
     return value.replace("\n", " ").replace("\r", "")
-    
+
+
 ################################################################################
 class NewsletterFriendlyCssNode(template.Node):
-
+    """css in tags attributes"""
     def __init__(self, nodelist_content, css):
         self.css = css
         self.nodelist_content = nodelist_content
 
     def render(self, context):
+        """to html"""
         content = self.nodelist_content.render(context)
         if context.get('by_email', False):
             soup = BeautifulSoup(content)
@@ -98,7 +108,7 @@ class NewsletterFriendlyCssNode(template.Node):
 
 @register.tag
 def nlf_css(parser, token):
-    #Newsletter friendly CSS
+    """Newsletter friendly CSS"""
     args = token.split_contents()
     css = {}
     for item in args[1:]:
@@ -109,8 +119,10 @@ def nlf_css(parser, token):
     token = parser.next_token()
     return NewsletterFriendlyCssNode(nodelist, css)
 
+
 @register.filter
 def normalize_utf8_to_ascii(ustr):
+    """utf to ascii"""
     try:
         return unicodedata.normalize('NFKD', ustr).encode('ascii','ignore')
     except TypeError:
@@ -119,19 +131,23 @@ def normalize_utf8_to_ascii(ustr):
 
 @register.filter(name='is_checkbox')
 def is_checkbox(field):
+    """is checkbox"""
     field = getattr(field, 'field', field) # get the field attribute of the field or the field itself
     return field.widget.__class__.__name__ == CheckboxInput().__class__.__name__
-    
+
+
 @register.filter
-def index(seq, index):
+def index(seq, index_val):
+    """get index"""
     try:
-        return seq[index]
+        return seq[index_val]
     except IndexError:
         return None
 
+
 ################################################################################
 class CoopCategoryNode(template.Node):
-
+    """get category in template context"""
     def __init__(self, cat_slug, var_name):
         cat = cat_slug.strip("'").strip('"')
         self.cat_var, self.cat = None, None
@@ -142,6 +158,7 @@ class CoopCategoryNode(template.Node):
         self.var_name = var_name
 
     def render(self, context):
+        """to html"""
         if self.cat_var:
             self.cat = self.cat_var.resolve(context)
         try:
@@ -154,7 +171,7 @@ class CoopCategoryNode(template.Node):
 
 @register.tag
 def coop_category(parser, token):
-    #Newsletter friendly CSS
+    """get category in template context"""
     args = token.split_contents()
     cat_slug = args[1]
     var_name = args[2]
@@ -163,10 +180,13 @@ def coop_category(parser, token):
 
 @register.filter
 def basename(fullname):
+    """os.path.basename"""
     return os.path.basename(fullname)
 
+
 @register.filter
 def get_parts(list_of_objs, number_of_parts):
+    """slice"""
     nb_objs = len(list_of_objs)
     nb_by_part, extra_nb = nb_objs/number_of_parts, nb_objs % number_of_parts
     parts = []
@@ -177,8 +197,10 @@ def get_parts(list_of_objs, number_of_parts):
         parts.append(list_of_objs[start_index:stop_index])
     return parts
 
+
 @register.filter
 def get_part(list_of_objs, partionning):
+    """slices"""
     which_part, number_of_parts = [int(x) for x in partionning.split("/")]
     parts = get_parts(list_of_objs, number_of_parts)
     return parts[which_part-1]
@@ -186,7 +208,7 @@ def get_part(list_of_objs, partionning):
 
 ################################################################################
 class ImageListNode(template.Node):
-
+    """image list"""
     def __init__(self, filter_name, var_name):
         stripped_filter_name = filter_name.strip("'").strip('"')
         self.filter_var, self.filter_value = None, None
@@ -205,6 +227,7 @@ class ImageListNode(template.Node):
 
 @register.tag
 def coop_image_list(parser, token):
+    """image list"""
     args = token.split_contents()
     try:
         filter_name = args[1]
@@ -219,12 +242,13 @@ def coop_image_list(parser, token):
 DEFAULT_ACCEPT_COOKIE_MESSAGE_TEMPLATE = 'coop_cms/_accept_cookies_message.html'
 
 class ShowAcceptCookieMessageNode(template.Node):
-
+    """accept cookie message"""
     def __init__(self, template_name):
         self.template_name = template_name or DEFAULT_ACCEPT_COOKIE_MESSAGE_TEMPLATE
         super(ShowAcceptCookieMessageNode, self).__init__()
 
     def render(self, context):
+        """to html"""
         request = context.get('request', None)
         if not request.session.get('hide_accept_cookie_message', False):
             t = get_template(self.template_name)
@@ -232,12 +256,13 @@ class ShowAcceptCookieMessageNode(template.Node):
         else:
             return ""
 
+
 @register.tag
 def show_accept_cookie_message(parser, token):
+    """show accept cookie message"""
     args = token.split_contents()
     if len(args) > 1:
         template_name = args[1].strip('"').strip('"')
     else:
         template_name = ""
     return ShowAcceptCookieMessageNode(template_name)
-
